@@ -1,23 +1,23 @@
 #' Run APSIM Simulations from R
 #' 
 #' This function will run one or many APSIM simulations and read the output into R 
-#' in the form of a list.  If the simulation does not run for some reason then 
+#' in the form of a list of data frames.  If the simulation does not run for some reason then 
 #' an error is returned.
 #' 
 #' The only required input is the path to the APSIM executable (APSIM.exe) usually found in the "Model"
 #' subfolder of the APSIM installation. By default, it is assumed the current working directory contains the .apsim file(s)
 #' to be run.  If that is not the case then the directory containing the .apsim file(s) to be run
-#' should be specified by \code{wd}.  One can specify a list of .apsim files to be run within the
+#' should be specified by the \code{wd} argument.  One can specify a list of .apsim files to be run within the
 #' directory \code{wd} using the \code{files} argument.  If the \code{files} argument is left blank then all 
 #' .apsim files within the directory specified by \code{wd} are run. 
-#' The results for each .apsim file that is run is an element of the list that is returned.  
+#' The results for each .apsim file is saved as a data frame which are complied into a list.  
 #' Each element of the list is of the class \code{"apsim"}, which has its own \code{print} and \code{plot} routines.
 #' 
 #' @name apsim
 #' @param exe  path to the APSIM executable
 #' @param wd  working directory containing the .apsim files to be run; defaults to the current working directory
 #' @param files  .apsim files to be run; if left empty all .apsim files in \code{wd} will be run
-#' @return list of output files; each element corresponds to an .apsim file
+#' @return list of output files; each element of the list corresponds to an output file specified by the .apsim files executed
 #' @export
 #' @examples
 #' 
@@ -58,8 +58,9 @@ apsim<-function(exe, wd = getwd(), files = NULL){
   }
   
   nFiles<-length(files)
-  out_files<-rep(NA,nFiles)
-  
+  #Allow for multiple output files per simulation and record their names
+  out_files <- NULL
+
   for(i in 1:nFiles){  
     
     res <- suppressWarnings(system(paste(exe,addCommas(files[i]), sep = " "), show.output.on.console = FALSE))
@@ -69,14 +70,21 @@ apsim<-function(exe, wd = getwd(), files = NULL){
       stop("An error occured when trying to run APSIM.  Please check your arguments again, especially the path to APSIM.exe.")
     }
     
-    #Grab the name of the ouput file from the simulation file
-    out_files[i]<-paste(xmlAttrs(xmlParse(files[i])[["//simulation"]])[[1]],".out",sep="")
+    #Get the list of output files for simulation file i
+    noutsi <- xmlParse(files[i])["//outputfile"]
+    
+    #Extract the names of the output files 
+    for(j in 1:length(noutsi)){
+      out_files <- c(out_files,xmlValue(noutsi[[j]]["filename"][[1]]))
+    }
   }
   
 
-  results<-vector("list",nFiles)
-  skipline<-1
-  for(i in 1:nFiles){
+  n_out_files <- length(out_files)
+  results<-vector("list",n_out_files)
+
+  for(i in 1:n_out_files){
+    skipline<-1
     res<-try(read.table(out_files[i],skip=skipline,header=T),TRUE)
     
     while(class(res)=="try-error" & skipline < 50){
@@ -84,35 +92,45 @@ apsim<-function(exe, wd = getwd(), files = NULL){
       res<-try(read.table(out_files[i],skip=skipline,header=T),TRUE)
     }
     
-    res<-res[-1,]
+    if(skipline<50){
+      
+      res<-res[-1,]
+      res_col_names <- colnames(res)
     
-    if("Date"%in%colnames(res)) res$Date<-dmy(res$Date)
+      if("Date"%in%res_col_names){
+        res$Date<-dmy(res$Date)
+        res_col_names <- res_col_names[-which(res_col_names=="Date")]
+      }
     
-    for(j in 2:ncol(res)){
-      res[,j]<-as.numeric(as.character(res[,j])) #Coerce each output to be numeric
+      for(j in res_col_names){
+        res[,which(colnames(res)==j)]<-as.numeric(as.character(res[,which(colnames(res)==j)])) #Coerce each output to be numeric
+      }
+      class(res)<-c("apsim","data.frame")
+      results[[i]]<-res
+      
+    }else{
+      warning(paste0("The file \"",out_files[i],"\" could not be read properly.  Please check it exists and is nonempty."))
     }
-    class(res)<-c("apsim","data.frame")
-    results[[i]]<-res
   }
   
   setwd(oldWD)
   
-  if(nFiles==1){return(res)
-  }else{
-    names(results)<-gsub(".apsim$","",files)
-    return(results)
+  if(n_out_files==1){
+    return(res)
   }
   
+  names(results)<-gsub(".out$","",out_files)
+  return(results)
   
 }
 
 #' Access Example APSIM Simulations
 #' 
 #' Standard APSIM simulations are provided by the default APSIM installation.
-#' \code{apsim_expample} moves those example files into the working directory \code{wd} so you can run them
+#' \code{apsim_example} moves those example files into the working directory \code{wd} so you can run them
 #' or edit them using \code{\link{apsim}} and \code{\link{edit_apsim}}, respectively.  Generally the
 #' example simulations must be moved because the output file is written to the directory containing
-#' the .apsim file and the ability to write in the "Program Files" folder is limited in most cases.
+#' the .apsim file and the ability to write in the "Program Files" can be limited in some cases.
 #' 
 #' 
 #' @name example_apsim
@@ -134,6 +152,7 @@ apsim<-function(exe, wd = getwd(), files = NULL){
 #' 
 #' apsimExe <-"C:/Program Files (x86)/Apsim75-r3008/Model/Apsim.exe"
 #' results <- apsim(exe = apsimExe, wd = apsimWd, files = toRun)
+#' plot(results[[1]])
 #' }
 
 example_apsim<-function(path, wd = getwd(), files = NULL,...){
